NOTE: This patch has been committed.
lisp/ChangeLog addition:
2005-02-09 Aidan Kehoe <kehoea(a)parhasard.net>
* mule/european.el: Create the 8859-16 character set and coding system.
* mule/european.el (latin-iso8859-16): Make the character set available.
2005-02-09 Aidan Kehoe <kehoea(a)parhasard.net>
* unicode.el (load-unicode-tables):
Initialise mapping tables for ISO
8859-16--cf. s3tk6pieyuk.fsf(a)magellan.suse.de , DOUBLE LOW-9
QUOTATION MARK is very much used for German and in Central Europe.
XEmacs Trunk source patch:
Diff command: cvs -q diff -u
Files affected: lisp/mule/european.el lisp/unicode.el
Index: lisp/unicode.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/lisp/unicode.el,v
retrieving revision 1.10
diff -u -r1.10 unicode.el
--- lisp/unicode.el 2005/02/08 23:59:51 1.10
+++ lisp/unicode.el 2005/02/09 15:19:05
@@ -101,6 +101,7 @@
;; "8859-13.TXT"
("8859-14.TXT" latin-iso8859-14 #xA0 #xFF #x-80)
("8859-15.TXT" latin-iso8859-15 #xA0 #xFF #x-80)
+ ("8859-16.TXT" latin-iso8859-16 #xA0 #xFF #x-80)
("8859-2.TXT" latin-iso8859-2 #xA0 #xFF #x-80)
("8859-3.TXT" latin-iso8859-3 #xA0 #xFF #x-80)
("8859-4.TXT" latin-iso8859-4 #xA0 #xFF #x-80)
Index: lisp/mule/european.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/lisp/mule/european.el,v
retrieving revision 1.9
diff -u -r1.9 european.el
--- lisp/mule/european.el 2002/06/04 06:04:29 1.9
+++ lisp/mule/european.el 2005/02/09 15:19:10
@@ -27,7 +27,7 @@
;;; Commentary:
;; For Europeans, six coded character sets ISO8859-1,2,3,4,9 are supported.
;; Note: ISO 8859/15 (Latin-9) is supported via the latin-unity package.
;; #### latin.el would be a better name for this file.
@@ -131,6 +131,27 @@
long-name "RHP of Latin-8 (ISO 8859-14)"
))
+(make-charset 'latin-iso8859-16
+ "Right-Hand Part of Latin Alphabet 10 (ISO/IEC 8859-16)"
+ '(dimension
+ 1
+ registry "ISO8859-16"
+ chars 96
+ columns 1
+ direction l2r
+ final ?f ; octet 06/06; cf ISO-IR 226
+ graphic 1
+ short-name "RHP of Latin-10"
+ long-name "RHP of Latin-10 (ISO 8859-16)"
+ ))
+
+(loop for c from 64 to 127
+ do (modify-syntax-entry (make-char 'latin-iso8859-16 c) "w"))
+(mapc (lambda (c)
+ (modify-syntax-entry (make-char 'latin-iso8859-16 c) "w"))
+ '(#xA1 #xA2 #xA3 #xA6 #xA8 #xAA #xAC #xAE #xAF
+ #xB3 #xB4 #xB5 #xB8 #xB9 #xBA #xBC #xBD #xBE #xBF))
+
;; For syntax of Latin-1 characters.
(loop for c from 64 to 127 ; from ',A@(B' to ',A(B'
@@ -350,6 +371,15 @@
charset-g3 t
mnemonic "MIME/Ltn-5"
))
+
+;; Add a coding system for ISO 8859-16.
+(make-coding-system
+ 'iso-8859-16 'iso2022 "MIME ISO-8859-16"
+ '(charset-g0 ascii
+ charset-g1 latin-iso8859-16
+ charset-g2 t ; grrr
+ charset-g3 t ; grrr
+ mnemonic "MIME/Ltn-10"))
(loop for ((charset codesys default-input nice-charset-1 nice-charset-2
supported-langs ;; a list if the doc string is replaced
@@ -27,7 +27,7 @@
;;; Commentary:
-;; For Europeans, six coded character sets ISO8859-1,2,3,4,9 are supported.
+;; For Europeans, seven coded character sets ISO8859-1,2,3,4,9,10 are supported.
;; Note: ISO 8859/15 (Latin-9) is supported via the latin-unity package.
;; #### latin.el would be a better name for this file.
--
“Ah come on now Ted, a Volkswagen with a mind of its own, driving all over
the place and going mad, if that’s not scary I don’t know what is.”